#
# spec file for package ghc-dpor
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name dpor
Name:           ghc-%{pkg_name}
Version:        0.2.0.0
Release:        8.7
Summary:        A generic implementation of dynamic partial-order reduction (DPOR) for testing arbitrary models of concurrency
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-semigroups-devel

%description
We can characterise the state of a concurrent computation by considering the
ordering of dependent events. This is a partial order: independent events can
be performed in any order without affecting the result. DPOR is a technique for
computing these partial orders at run-time, and only testing one total order
for each partial order. This cuts down the amount of work to be done
significantly. In particular, this package implemented bounded partial-order
reduction, which is a further optimisation. Only schedules within some *bound*
are considered.

* DPOR with no schedule bounding is __complete__, it /will/ find all distinct
executions!

* DPOR with schedule bounding is __incomplete__, it will only find all distinct
executions /within the bound/!

__Caution:__ The fundamental assumption behind DPOR is that the *only* source
of nondeterminism in your program is the scheduler. Or, to put it another way,
if you execute the same program with the same schedule twice, you get the same
result. If you are using this library in combination with something which
performs I/O, be *very* certain that this is the case!

See the <https://github.com/barrucadu/dejafu README> for more details.

For details on the algorithm, albeit presented in a very imperative way, see
/Bounded partial-order reduction/, K. Coons, M. Musuvathi, and K.
McKinley (2013), available at
<http://research.microsoft.com/pubs/202164/bpor-oopsla-2013.pdf>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.2.0.0 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.1.0.1 revision 0 with cabal2obs.
